@@ -1,6 +1,6 @@
 use strict; use warnings;
 package YAML::Any;
-our $VERSION = '1.28_001';
+our $VERSION = '1.02';
 
 use Exporter ();
 
@@ -29,7 +29,6 @@ my @dump_options = qw(
 my @load_options = qw(
     UseCode
     LoadCode
-    Preserve
 );
 
 my @implementations = qw(
@@ -47,7 +46,6 @@ sub import {
 
 sub Dump {
     no strict 'refs';
-    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@dump_options) {
         my $var = "$implementation\::$option";
@@ -60,7 +58,6 @@ sub Dump {
 
 sub DumpFile {
     no strict 'refs';
-    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@dump_options) {
         my $var = "$implementation\::$option";
@@ -73,7 +70,6 @@ sub DumpFile {
 
 sub Load {
     no strict 'refs';
-    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@load_options) {
         my $var = "$implementation\::$option";
@@ -86,7 +82,6 @@ sub Load {
 
 sub LoadFile {
     no strict 'refs';
-    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@load_options) {
         my $var = "$implementation\::$option";
